import { Entity } from './types';
import { Action, ActionCreator } from 'redux';
import { ThunkAction } from 'redux-thunk';
/**
 * @todo add error action and make functions return that error when the requests don't succeed.
 */
/**
 * The RESTReduxCRUD module contains four redux objects: actions, actionTypes, reducers, and selectors.
 * RESTReduxCRUD has a peer dependency of {@link https://www.npmjs.com/package/redux-thunk | Redux Thunk} to avoid importing Redux's dispatch functionality into each file that depends on dispatch.
 * @namespace RESTReduxCRUD
 */
/**
 * Dynamically namespaced RESTful Redux CRUD actions for Queries, Datasets and DataSources entities.
 * @memberof RESTReduxCRUD
 * @namespace
 * @param {string} namespace Desired namespace for these actions eg. "queries".
 * @param {path} restResource Rest path that the actions will live under eg. "/query".
 * @returns {object} Set of CRUD actions accessible within the actions object.
 * @see See the related {@link RESTReduxCRUD.selectors|selectors} to check on action status and returned results where applicable.
 */
declare const actions: <T extends Entity>(namespace: string, restResource: string) => {
    list: ActionCreator<ThunkAction<Promise<Action>, Readonly<{
        entities: ReadonlyArray<T>;
        pendingEdits: ReadonlyArray<T>;
        listPending: boolean;
        deletePending: boolean;
        addPending: boolean;
    }>, void>>;
    add: ActionCreator<ThunkAction<Promise<Action>, Readonly<{
        entities: ReadonlyArray<T>;
        pendingEdits: ReadonlyArray<T>;
        listPending: boolean;
        deletePending: boolean;
        addPending: boolean;
    }>, void>>;
    edit: ActionCreator<ThunkAction<Promise<Action>, Readonly<{
        entities: ReadonlyArray<T>;
        pendingEdits: ReadonlyArray<T>;
        listPending: boolean;
        deletePending: boolean;
        addPending: boolean;
    }>, void>>;
    del: ActionCreator<ThunkAction<Promise<Action>, Readonly<{
        entities: ReadonlyArray<T>;
        pendingEdits: ReadonlyArray<T>;
        listPending: boolean;
        deletePending: boolean;
        addPending: boolean;
    }>, void>>;
};
export default actions;
